==> calamares_3.2.14.orig.tar.gz: calamares-3.2.14/src/libcalamaresui/viewpages/PythonQtUtilsWrapper.cpp <==
/* === This file is part of Calamares - <https://github.com/calamares> ===
 *
 *   Copyright 2016, Teo Mrnjavac <teo@kde.org>
 *
 *   Calamares is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   Calamares is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
 */

#include "PythonQtUtilsWrapper.h"

#include "utils/CalamaresUtilsSystem.h"
#include "utils/Logger.h"
#include "utils/String.h"

#include <PythonQt.h>


Utils::Utils( QObject* parent )
    : QObject( parent )
    , m_exceptionCxt( PythonQt::self()->createUniqueModule() )
{
    PythonQt::self()->evalScript( m_exceptionCxt, "import subprocess" );
}


void
Utils::debug( const QString& s ) const
{
    cDebug() << "PythonQt DBG>" << s;
}


int
Utils::mount( const QString& device_path,
              const QString& mount_point,
              const QString& filesystem_name,
              const QString& options ) const
{
    return CalamaresUtils::System::instance()->mount( device_path, mount_point, filesystem_name, options );
}


int
Utils::target_env_call( const QString& command, const QString& stdin, int timeout ) const
{
    return CalamaresUtils::System::instance()->targetEnvCall(
        command, QString(), stdin, std::chrono::seconds( timeout > 0 ? timeout : 0 ) );
}


int
Utils::target_env_call( const QStringList& args, const QString& stdin, int timeout ) const
{
    return CalamaresUtils::System::instance()->targetEnvCall(
        args, QString(), stdin, std::chrono::seconds( timeout > 0 ? timeout : 0 ) );
}


int
Utils::check_target_env_call( const QString& command, const QString& stdin, int timeout ) const
{
    int ec = target_env_call( command, stdin, timeout );
    return _handle_check_target_env_call_error( ec, command );
}


int
Utils::check_target_env_call( const QStringList& args, const QString& stdin, int timeout ) const
{
    int ec = target_env_call( args, stdin, timeout );
    return _handle_check_target_env_call_error( ec, args.join( ' ' ) );
}


QString
Utils::check_target_env_output( const QString& command, const QString& stdin, int timeout ) const
{
    QString output;
    int ec = CalamaresUtils::System::instance()->targetEnvOutput(
        command, output, QString(), stdin, std::chrono::seconds( timeout > 0 ? timeout : 0 ) );
    _handle_check_target_env_call_error( ec, command );
    return output;
}


QString
Utils::check_target_env_output( const QStringList& args, const QString& stdin, int timeout ) const
{
    QString output;
    int ec = CalamaresUtils::System::instance()->targetEnvOutput(
        args, output, QString(), stdin, std::chrono::seconds( timeout > 0 ? timeout : 0 ) );
    _handle_check_target_env_call_error( ec, args.join( ' ' ) );
    return output;
}


QString
Utils::obscure( const QString& string ) const
{
    return CalamaresUtils::obscure( string );
}


int
Utils::_handle_check_target_env_call_error( int ec, const QString& cmd ) const
{
    if ( ec )
    {
        QString raise = QString( "raise subprocess.CalledProcessError(%1,\"%2\")" ).arg( ec ).arg( cmd );
        PythonQt::self()->evalScript( m_exceptionCxt, raise );
    }
    return ec;
}

==> calamares_3.2.20.orig.tar.gz: calamares-3.2.20/src/libcalamaresui/viewpages/PythonQtUtilsWrapper.cpp <==
/* === This file is part of Calamares - <https://github.com/calamares> ===
 *
 *   Copyright 2016, Teo Mrnjavac <teo@kde.org>
 *   Copyright 2019, Adriaan de Groot <groot@kde.org>
 *
 *   Calamares is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   Calamares is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with Calamares. If not, see <http://www.gnu.org/licenses/>.
 */

#include "PythonQtUtilsWrapper.h"

#include "partition/Mount.h"
#include "utils/CalamaresUtilsSystem.h"
#include "utils/Logger.h"
#include "utils/String.h"

#include <PythonQt.h>


Utils::Utils( QObject* parent )
    : QObject( parent )
    , m_exceptionCxt( PythonQt::self()->createUniqueModule() )
{
    PythonQt::self()->evalScript( m_exceptionCxt, "import subprocess" );
}


void
Utils::debug( const QString& s ) const
{
    cDebug() << "PythonQt DBG>" << s;
}


int
Utils::mount( const QString& device_path,
              const QString& mount_point,
              const QString& filesystem_name,
              const QString& options ) const
{
    return CalamaresUtils::Partition::mount( device_path, mount_point, filesystem_name, options );
}


int
Utils::target_env_call( const QString& command, const QString& stdin, int timeout ) const
{
    return CalamaresUtils::System::instance()->targetEnvCall(
        command, QString(), stdin, std::chrono::seconds( timeout > 0 ? timeout : 0 ) );
}


int
Utils::target_env_call( const QStringList& args, const QString& stdin, int timeout ) const
{
    return CalamaresUtils::System::instance()->targetEnvCall(
        args, QString(), stdin, std::chrono::seconds( timeout > 0 ? timeout : 0 ) );
}


int
Utils::check_target_env_call( const QString& command, const QString& stdin, int timeout ) const
{
    int ec = target_env_call( command, stdin, timeout );
    return _handle_check_target_env_call_error( ec, command );
}


int
Utils::check_target_env_call( const QStringList& args, const QString& stdin, int timeout ) const
{
    int ec = target_env_call( args, stdin, timeout );
    return _handle_check_target_env_call_error( ec, args.join( ' ' ) );
}


QString
Utils::check_target_env_output( const QString& command, const QString& stdin, int timeout ) const
{
    QString output;
    int ec = CalamaresUtils::System::instance()->targetEnvOutput(
        command, output, QString(), stdin, std::chrono::seconds( timeout > 0 ? timeout : 0 ) );
    _handle_check_target_env_call_error( ec, command );
    return output;
}


QString
Utils::check_target_env_output( const QStringList& args, const QString& stdin, int timeout ) const
{
    QString output;
    int ec = CalamaresUtils::System::instance()->targetEnvOutput(
        args, output, QString(), stdin, std::chrono::seconds( timeout > 0 ? timeout : 0 ) );
    _handle_check_target_env_call_error( ec, args.join( ' ' ) );
    return output;
}


QString
Utils::obscure( const QString& string ) const
{
    return CalamaresUtils::obscure( string );
}


int
Utils::_handle_check_target_env_call_error( int ec, const QString& cmd ) const
{
    if ( ec )
    {
        QString raise = QString( "raise subprocess.CalledProcessError(%1,\"%2\")" ).arg( ec ).arg( cmd );
        PythonQt::self()->evalScript( m_exceptionCxt, raise );
    }
    return ec;
}
